==> cppad_2017.00.00.0.orig.tar.gz: cppad-20170000.0/doc/_reverse_any_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'funeval.xml',
'reverse.xml',
'reverse_any.xml'
];
var list_down3 = [
'independent.xml',
'funconstruct.xml',
'dependent.xml',
'abort_recording.xml',
'seq_property.xml',
'funeval.xml',
'drivers.xml',
'funcheck.xml',
'optimize.xml',
'check_for_nan.xml'
];
var list_down2 = [
'forward.xml',
'reverse.xml',
'sparse.xml'
];
var list_down1 = [
'reverse_one.xml',
'reverse_two.xml',
'reverse_any.xml'
];
var list_down0 = [
'reverse_three.cpp.xml',
'reverse_checkpoint.cpp.xml'
];
var list_current0 = [
'reverse_any.xml#Syntax',
'reverse_any.xml#Purpose',
'reverse_any.xml#Notation',
'reverse_any.xml#Notation.u^(k)',
'reverse_any.xml#Notation.X(t, u)',
'reverse_any.xml#Notation.Y(t, u)',
'reverse_any.xml#Notation.w^(k)',
'reverse_any.xml#Notation.W(u)',
'reverse_any.xml#f',
'reverse_any.xml#q',
'reverse_any.xml#w',
'reverse_any.xml#dw',
'reverse_any.xml#First Order',
'reverse_any.xml#Second Order',
'reverse_any.xml#Vector',
'reverse_any.xml#Example'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2018.00.00.0.orig.tar.gz: cppad-20180000.0/doc/_reverse_any_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'reverse.xml',
'reverse_any.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'record_adfun.xml',
'drivers.xml',
'forward.xml',
'reverse.xml',
'sparsity_pattern.xml',
'sparse_derivative.xml',
'optimize.xml',
'abs_normal.xml',
'funcheck.xml',
'check_for_nan.xml'
];
var list_down1 = [
'reverse_one.xml',
'reverse_two.xml',
'reverse_any.xml',
'subgraph_reverse.xml'
];
var list_down0 = [
'reverse_three.cpp.xml',
'reverse_checkpoint.cpp.xml'
];
var list_current0 = [
'reverse_any.xml#Syntax',
'reverse_any.xml#Purpose',
'reverse_any.xml#Notation',
'reverse_any.xml#Notation.u^(k)',
'reverse_any.xml#Notation.X(t, u)',
'reverse_any.xml#Notation.Y(t, u)',
'reverse_any.xml#Notation.w^(k)',
'reverse_any.xml#Notation.W(u)',
'reverse_any.xml#f',
'reverse_any.xml#q',
'reverse_any.xml#w',
'reverse_any.xml#dw',
'reverse_any.xml#First Order',
'reverse_any.xml#Second Order',
'reverse_any.xml#Vector',
'reverse_any.xml#Example'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
